==> v8.3.zip: ru_twords_ru_tw/bible/other/overseer.md <==
# епископ

## Определение:

Смотритель или надзиратель – это человек, который следит за порядком и заботится о вверенных в его попечение людях.

* В Ветхом завете “надзирателем” или “смотрителем” называли надсмотрщика за работниками. Он распределял работу, следил, чтобы всё было сделано вовремя и правильно, а так же заботился об обеспечении работников необходимыми материалами, питанием, одеждой, ночлегом и т.д.
* В раннехристианских общинах слово “смотритель” (епископ) стали использовать как синоним слову “старейшина” (“пресвитер”) – то есть для обозначения руководителя общины.
* По-гречески слово “надзиратель” – это επισκοπος (episkopos, что буквально значит “смотрящий сверху” (“надзиратель”, “надсмотрщик”), и впоследствии (начиная со II-III веков) слово “епископ” стало использоваться для обозначения руководителя нескольких церковных общин в регионе – как обозначение человека, которому подчинялись старейшины нескольких христианских общин. Однако во времена написания Нового завета слово “епископ” ещё не имело такого значения и обозначало то же самое, что и слово “старейшина”, “руководитель общины”: так, например, в послании Титу Павел называет руководителя общины сначала “старейшиной”, а затем “смотрителем”.
* Апостол Павел называл смотрителей “пастырями, заботящимися о Божьем стаде”. Смотритель сравнивался с пастухом, присматривающим за стадом. В практике раннехристианских церквей он должен был охранять верующих и защищать верующих от лжеучений и негативного влияния окружающего мира.
* “Смотритель”, “пресвитер” и “пастор” — это одна и та же руководящая должность.

## Варианты перевода

* Слово “смотритель” можно перевести как “управляющий”, “попечитель”, “руководитель”.
* Когда речь идёт о лидере церкви, это слово можно перевести как “руководитель”, “старейшина”, “попечитель” или фразой “тот, кто заботится о нуждах церкви”, “тот, кто следит за порядком и помогает восполнить нужды верующих”, “духовный наставник”.

(См. также: [церковь](../kt/church.md), [пресвитер](../other/elder.md), [пастор](../kt/pastor.md), [пастух](../other/shepherd.md))

## Ссылки на библейский текст:

* [1 Пар. 26:31-32](rc://*/tn/help/1ch/26/31)
* [1 Тим. 3:2](rc://*/tn/help/1ti/03/02)
* [Деян. 20:28](rc://*/tn/help/act/20/28)
* [Быт. 41:33-34](rc://*/tn/help/gen/41/33)
* [Флп. 1:1](rc://*/tn/help/php/01/01)

## Данные о слове:

* Номера Стронга: H5329, H6485, H6496, H7860, H8104, G1983, G1984, G1985

==> v9.2.zip: ru_twords_ru_tw/bible/other/overseer.md <==
# епископ

## Определение:

Смотритель или надзиратель – это человек, который следит за порядком и заботится о вверенных в его попечение людях.

* В Ветхом завете “надзирателем” или “смотрителем” называли надсмотрщика за работниками. Он распределял работу, следил, чтобы всё было сделано вовремя и правильно, а так же заботился об обеспечении работников необходимыми материалами, питанием, одеждой, ночлегом и т.д.
* В раннехристианских общинах слово “смотритель” (епископ) стали использовать как синоним слову “старейшина” (“пресвитер”) – то есть для обозначения руководителя общины.
* По-гречески слово “надзиратель” – это επισκοπος (episkopos, что буквально значит “смотрящий сверху” (“надзиратель”, “надсмотрщик”), и впоследствии (начиная со II-III веков) слово “епископ” стало использоваться для обозначения руководителя нескольких церковных общин в регионе – как обозначение человека, которому подчинялись старейшины нескольких христианских общин. Однако во времена написания Нового завета слово “епископ” ещё не имело такого значения и обозначало то же самое, что и слово “старейшина”, “руководитель общины”: так, например, в послании Титу Павел называет руководителя общины сначала “старейшиной”, а затем “смотрителем”.
* Апостол Павел называл смотрителей “пастырями, заботящимися о Божьем стаде”. Смотритель сравнивался с пастухом, присматривающим за стадом. В практике раннехристианских церквей он должен был охранять верующих и защищать верующих от лжеучений и негативного влияния окружающего мира.
* “Смотритель”, “пресвитер” и “пастор” — это одна и та же руководящая должность.

## Варианты перевода

* Слово “смотритель” можно перевести как “управляющий”, “попечитель”, “руководитель”.
* Когда речь идёт о лидере церкви, это слово можно перевести как “руководитель”, “старейшина”, “попечитель” или фразой “тот, кто заботится о нуждах церкви”, “тот, кто следит за порядком и помогает восполнить нужды верующих”, “духовный наставник”.

(См. также: [церковь](../kt/church.md), [пресвитер](../other/elder.md), [пастор](../kt/pastor.md), [пастух](../other/shepherd.md))

## Ссылки на библейский текст:

* [1 Пар. 26:31-32](rc://ru/tn/help/1ch/26/31)
* [1 Тим. 3:2](rc://ru/tn/help/1ti/03/02)
* [Деян. 20:28](rc://ru/tn/help/act/20/28)
* [Быт. 41:33-34](rc://ru/tn/help/gen/41/33)
* [Флп. 1:1](rc://ru/tn/help/php/01/01)

## Данные о слове:

* Номера Стронга: H5329, H6485, H6496, H7860, H8104, G1983, G1984, G1985
